Commit 258523f63e for wordpress.org

commit 258523f63e9d8c2b8764e04111c3671342c949d7
Author: audrasjb <audrasjb@git.wordpress.org>
Date:   Mon Apr 22 21:06:08 2024 +0000

    Toolbar: Replace "Edit Site" link with "Site Editor" in the Admin Toolbar.

    This changesets replaces the "Edit Site" link with "Site Editor" to avoid duplicate link anchors on multisite admin toolbar. The remaining "Edit site" link takes the user to the site editing screen in the network admin area (`network/site-info.php`) while the new "Site Editor" link takes the user to the site editor (`site-editor.php`).

    Follow-up to [52158]. See GB27135.

    Props johnbillion, sabernhardt, audrasjb, johnjamesjacoby, pratiklondhe.
    Fixes #60977.



    Built from https://develop.svn.wordpress.org/trunk@58035


    git-svn-id: http://core.svn.wordpress.org/trunk@57501 1a063a9b-81f0-0310-95a4-ce76da25c4cd

diff --git a/wp-includes/version.php b/wp-includes/version.php
index 578f592309..ddea1d1064 100644
--- a/wp-includes/version.php
+++ b/wp-includes/version.php
@@ -16,7 +16,7 @@
  *
  * @global string $wp_version
  */
-$wp_version = '6.6-alpha-58034';
+$wp_version = '6.6-alpha-58035';

 /**
  * Holds the WordPress DB revision, increments when changes are made to the WordPress DB schema.
diff --git a/wp-includes/admin-bar.php b/wp-includes/admin-bar.php
index d709de125c..3e1740f614 100644
--- a/wp-includes/admin-bar.php
+++ b/wp-includes/admin-bar.php
@@ -451,7 +451,7 @@ function wp_admin_bar_site_menu( $wp_admin_bar ) {
 }

 /**
  * Adds the "Edit site" link to the Toolbar.
  *
  * @since 5.9.0
  * @since 6.3.0 Added `$_wp_current_template_id` global for editing of current template directly from the admin bar.
@@ -476,7 +476,7 @@ function wp_admin_bar_edit_site_menu( $wp_admin_bar ) {
 	$wp_admin_bar->add_node(
 		array(
 			'id'    => 'site-editor',
-			'title' => __( 'Edit site' ),
+			'title' => __( 'Site Editor' ),
 			'href'  => add_query_arg(
 				array(
 					'postType' => 'wp_template',
@@ -451,7 +451,7 @@ function wp_admin_bar_site_menu( $wp_admin_bar ) {

 /**
- * Adds the "Edit site" link to the Toolbar.
+ * Adds the "Site Editor" link to the Toolbar.
  *
  * @since 5.9.0